@@ -14,8 +14,10 @@ from .meters.label         import MetersLabel
 from .meters.line_edit     import MetersLineEdit
 from .ohms.label           import OhmsLabel
 from .ohms.line_edit       import OhmsLineEdit
+from .points.line_edit     import PointsLineEdit
 from .ports.label          import PortsLabel
 from .ports.line_edit      import PortsLineEdit
+from .seconds.line_edit    import SecondsLineEdit
 from .touchstone           import TouchstoneWidget
 from .user_corrections     import UserCorrectionsWidget
 from .value.label          import ValueLabel
